@@ -98,9 +98,9 @@ test_that("export as data frame", {
               columnFormats=list(NULL, NULL, NULL, "%.2f"))
 
   # output as data frame
-  df <- tbl$asDataFrame(firstRowAsColumnNames=TRUE, rawValue=TRUE)
+  df <- tbl$asDataFrame(firstRowAsColumnNames=TRUE, rawValue=TRUE, stringsAsFactors=FALSE)
   # prepStr(paste(as.character(df), sep=" ", collapse=" "))
-  text <- "c(5334, 5336, 5338) c(1, 3, 2) c(5, 8, 6) c(0.34452354, 0.4732543, 1.3443243)"
+  text <- "c(5334, 5336, 5338) c(\"Apple\", \"Orange\", \"Banana\") c(5, 8, 6) c(0.34452354, 0.4732543, 1.3443243)"
 
   expect_identical(paste(as.character(df), sep=" ", collapse=" "), text)
 })
